==> RSTouchscreenNG-1.3.0.zip: RSTouchscreenNG/projects/front-ui/src/lib/services/ui-helper.service.ts <==
/* (C) 2016-2021 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Injectable} from "@angular/core";
import {RepetierServer, PrinterAction, PrintersAction} from "binding";
import type {PrintersState, PrinterState, RepetierState} from "binding";
import {RSIntKeyboard} from "../modals/int-keyboard.service";
import {RSSelect} from "../modals/select.service";
import {RSModal} from "../modals/rsModal.component";
import {Observable} from "rxjs";
import {Store} from "@ngrx/store";

@Injectable()
export class RSUIHelper {
  printers$: Observable<PrintersState>;
  active: PrinterState;
  printers: PrintersState;

  constructor(public server: RepetierServer,
              private intKbd: RSIntKeyboard,
              private rsselect: RSSelect,
              private store: Store<RepetierState>,
              private modal: RSModal,
              private printerAction: PrinterAction,
              private printersAction: PrintersAction) {
    this.printers$ = store.select('printers');
    this.printers$.subscribe((p: PrintersState) => {
      this.printers = p;
      if (p.active) {
        this.active = p.printers[p.active];
      }
    });
  }

  flash(): void {
    const body = document.getElementsByTagName("body")[0];
    body.classList.add("flash");
    setTimeout(() => {
      body.classList.remove("flash");
    }, 200);
  }

  tempList(x: any): number[] {
    const r: number[] = [];
    for (const v of x) {
      r.push(parseInt(v.temp, 10));
    }
    return r;
  }

  removeDuplicates(x: number[]): number[] {
    return x.filter(function (elem, index, self) {
      return index === self.indexOf(elem);
    });
  }

  setExtruderTemp(eid) {
    this.intKbd.getInt(this.active.extruders[eid].tempSet, "<i class=\"" + this.printerAction.extruderIcon(this.active.slug, eid) + "\"></i> " + this.printerAction.extruderName(this.active.slug, eid), {
      min: 0,
      max: this.active.config.extruders[eid].maxTemp,
      unit: "°C",
      presets: this.removeDuplicates([0].concat(this.tempList(this.active.config.extruders[eid].temperatures)).concat([190, 200, 250]))
        .splice(0, 4).sort(function (a, b) {
          return a > b ? 1 : 0;
        })
    }).then(
      (v) => {
        this.printerAction.setExtruderTemperature(this.active.slug, eid, v);
      }, () => {
      }
    );
  }

  setBedTemp(idx: number) {
    this.intKbd.getInt(this.active.heatedBeds[idx].tempSet, "<i class=\"rs rs-heated-bed\"></i> " + "<?php _('Bed') ?> " + (this.active.heatedBeds.length === 1 ? "" : (idx + 1)), {
      min: 0,
      max: this.active.config.heatedBeds[idx].maxTemp,
      unit: "°C",
      presets: this.removeDuplicates([0].concat(this.tempList(this.active.config.heatedBeds[idx].temperatures)).concat([50, 60, 110]))
        .splice(0, 4).sort(function (a, b) {
          return a > b ? 1 : 0;
        })
    }).then(
      (v) => {
        this.printerAction.setBedTemperature(this.active.slug, idx, v);
      }, () => {
      }
    );
  }

  setChamberTemp(idx: number) {
    this.intKbd.getInt(this.active.heatedChambers[idx].tempSet, "<i class=\"rs rs-chamber\"></i> " + "<?php _('Heated Chamber') ?> " + (this.active.heatedChambers.length === 1 ? "" : (idx + 1)), {
      min: 0,
      max: this.active.config.heatedChambers[idx].maxTemp,
      unit: "°C",
      presets: this.removeDuplicates([0].concat(this.tempList(this.active.config.heatedChambers[idx].temperatures)).concat([0, 50, 60, 110]))
        .splice(0, 4).sort(function (a, b) {
          return a > b ? 1 : 0;
        })
    }).then(
      (v) => {
        this.printerAction.setChamberTemperature(this.active.slug, idx, v);
      }, () => {
      }
    );
  }

  setFan(idx: number) {
    this.intKbd.getInt(this.active.fans[idx].percent, "<i class=\"rs rs-fan\"></i> " + "<?php _('Fan') ?> " + (idx + 1), {
      min: 0,
      max: 100,
      unit: "%",
      presets: [0, 50, 75, 100]
    }).then(
      (v) => {
        this.printerAction.setFanPercent(this.active.slug, idx, v);
      }, () => {
      }
    );
  }

  setSpeed() {
    this.intKbd.getInt(this.active.speedMultiply, "<i class=\"rs rs-speed\"></i> " + "<?php _('Speed') ?>", {
      min: 25,
      max: 400,
      unit: "%",
      presets: [90, 100, 110, 125]
    }).then(
      (v) => {
        this.printerAction.setSpeedMultiply(this.active.slug, v);
      }, () => {
      }
    );
  }

  setFlow() {
    this.intKbd.getInt(this.active.flowMultiply, "<i class=\"rs rs-flow\"></i> " + "<?php _('Flow') ?>", {
      min: 0,
      max: 300,
      unit: "%",
      presets: [90, 95, 100, 105]
    }).then(
      (v) => {
        this.printerAction.setFlowMultiply(this.active.slug, v);
      }, () => {
      }
    );
  }

  selectExtruder() {
    const eList = [];
    for (let i = 0; i < this.active.extruders.length; i++) {
      eList.push({
        id: i,
        name: this.printerAction.extruderName(this.active.slug, i),
        icon: this.printerAction.extruderIcon(this.active.slug, i)
      });
    }
    this.rsselect.select(eList, "name", "<i class=\"rs rs-extruder\"></i> " + "<?php _('Select Extruder') ?>").then(
      (ex) => {
        this.printerAction.selectExtruder(this.active.slug, ex.id);
      }, () => {
      }
    );
  }

  selectPrinter() {
    const pList: PrinterState[] = [];
    for (const s of this.printers.sortedPrinters) {
      if (this.printers.printers[s].active && this.printers.printers[s].online) {
        pList.push(this.printers.printers[s]);
      }
    }
    this.rsselect.select(pList, "name", "<i class=\"rs rs-printer\"></i> " + "<?php _('Printers') ?>").then(
      (x) => {
        this.printersAction.setActiveSlug(x.slug);
      }, () => {
      }
    );
  }

  stopPrint() {
    this.modal.confirm("<?php _('Confirmation required') ?>", "<?php _('Really stop current print?') ?>").then(() => {
      this.printerAction.stopPrint(this.active.slug);
    }, () => {
    });
  }
}

==> RSTouchscreenNG-1.4.1.zip: RSTouchscreenNG/projects/front-ui/src/lib/services/ui-helper.service.ts <==
/* (C) 2016-2021 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Injectable} from "@angular/core";
import {RepetierServer, PrinterAction, PrintersAction} from "binding";
import type {PrintersState, PrinterState, RepetierState} from "binding";
import {RSIntKeyboard} from "../modals/int-keyboard.service";
import {RSSelect} from "../modals/select.service";
import {RSModal} from "../modals/rsModal.component";
import {Observable} from "rxjs";
import {Store} from "@ngrx/store";

@Injectable()
export class RSUIHelper {
  printers$: Observable<PrintersState>;
  active: PrinterState;
  printers: PrintersState;

  constructor(public server: RepetierServer,
              private intKbd: RSIntKeyboard,
              private rsselect: RSSelect,
              private store: Store<RepetierState>,
              private modal: RSModal,
              private printerAction: PrinterAction,
              private printersAction: PrintersAction) {
    this.printers$ = store.select("printers");
    this.printers$.subscribe((p: PrintersState) => {
      this.printers = p;
      if (p.active) {
        this.active = p.printers[p.active];
      }
    });
  }

  flash(): void {
    const body = document.getElementsByTagName("body")[0];
    body.classList.add("flash");
    setTimeout(() => {
      body.classList.remove("flash");
    }, 200);
  }

  tempList(x: any): number[] {
    const r: number[] = [];
    for (const v of x) {
      r.push(parseInt(v.temp, 10));
    }
    return r;
  }

  removeDuplicates(x: number[]): number[] {
    return x.filter(function (elem, index, self) {
      return index === self.indexOf(elem);
    });
  }

  setExtruderTemp(eid) {
    this.intKbd.getInt(this.active.extruders[eid].tempSet, "<i class=\"" + this.printerAction.extruderIcon(this.active.slug, eid) + "\"></i> " + this.printerAction.extruderName(this.active.slug, eid), {
      min: 0,
      max: this.active.config.extruders[eid].maxTemp,
      unit: "°C",
      presets: this.removeDuplicates([0].concat(this.tempList(this.active.config.extruders[eid].temperatures)).concat([190, 200, 250]))
        .splice(0, 4).sort(function (a, b) {
          return a > b ? 1 : 0;
        })
    }).then(
      (v) => {
        this.printerAction.setExtruderTemperature(this.active.slug, eid, v);
      }, () => {
      }
    );
  }

  setBedTemp(idx: number) {
    this.intKbd.getInt(this.active.heatedBeds[idx].tempSet, "<i class=\"rs rs-heated-bed\"></i> " + "<?php _('Bed') ?> " + (this.active.heatedBeds.length === 1 ? "" : (idx + 1)), {
      min: 0,
      max: this.active.config.heatedBeds[idx].maxTemp,
      unit: "°C",
      presets: this.removeDuplicates([0].concat(this.tempList(this.active.config.heatedBeds[idx].temperatures)).concat([50, 60, 110]))
        .splice(0, 4).sort(function (a, b) {
          return a > b ? 1 : 0;
        })
    }).then(
      (v) => {
        this.printerAction.setBedTemperature(this.active.slug, idx, v);
      }, () => {
      }
    );
  }

  setChamberTemp(idx: number) {
    this.intKbd.getInt(this.active.heatedChambers[idx].tempSet, "<i class=\"rs rs-chamber\"></i> " + "<?php _('Heated Chamber') ?> " + (this.active.heatedChambers.length === 1 ? "" : (idx + 1)), {
      min: 0,
      max: this.active.config.heatedChambers[idx].maxTemp,
      unit: "°C",
      presets: this.removeDuplicates([0].concat(this.tempList(this.active.config.heatedChambers[idx].temperatures)).concat([0, 50, 60, 110]))
        .splice(0, 4).sort(function (a, b) {
          return a > b ? 1 : 0;
        })
    }).then(
      (v) => {
        this.printerAction.setChamberTemperature(this.active.slug, idx, v);
      }, () => {
      }
    );
  }

  setFan(idx: number) {
    this.intKbd.getInt(this.active.fans[idx].percent, "<i class=\"rs rs-fan\"></i> " + "<?php _('Fan') ?> " + (idx + 1), {
      min: 0,
      max: 100,
      unit: "%",
      presets: [0, 50, 75, 100]
    }).then(
      (v) => {
        this.printerAction.setFanPercent(this.active.slug, idx, v);
      }, () => {
      }
    );
  }

  setSpeed() {
    this.intKbd.getInt(this.active.speedMultiply, "<i class=\"rs rs-speed\"></i> " + "<?php _('Speed') ?>", {
      min: 25,
      max: 400,
      unit: "%",
      presets: [90, 100, 110, 125]
    }).then(
      (v) => {
        this.printerAction.setSpeedMultiply(this.active.slug, v);
      }, () => {
      }
    );
  }

  setFlow() {
    this.intKbd.getInt(this.active.flowMultiply, "<i class=\"rs rs-flow\"></i> " + "<?php _('Flow') ?>", {
      min: 0,
      max: 300,
      unit: "%",
      presets: [90, 95, 100, 105]
    }).then(
      (v) => {
        this.printerAction.setFlowMultiply(this.active.slug, v);
      }, () => {
      }
    );
  }

  selectExtruder() {
    const eList = [];
    const config = this.printerAction.printers.printers[this.active.slug].config;
    for (let i = 0; i < this.active.extruders.length; i++) {
      if (config.extruders[i].toolType < 4) {
        eList.push({
          id: i,
          name: this.printerAction.extruderName(this.active.slug, i),
          icon: this.printerAction.extruderIcon(this.active.slug, i)
        });
      }
    }
    this.rsselect.select(eList, "name", "<i class=\"rs rs-extruder\"></i> " + "<?php _('Select Extruder') ?>").then(
      (ex) => {
        this.printerAction.selectExtruder(this.active.slug, ex.id);
      }, () => {
      }
    );
  }

  selectPrinter() {
    const pList: PrinterState[] = [];
    for (const s of this.printers.sortedPrinters) {
      if (this.printers.printers[s].active && this.printers.printers[s].online) {
        pList.push(this.printers.printers[s]);
      }
    }
    this.rsselect.select(pList, "name", "<i class=\"rs rs-printer\"></i> " + "<?php _('Printers') ?>").then(
      (x) => {
        this.printersAction.setActiveSlug(x.slug);
      }, () => {
      }
    );
  }

  stopPrint() {
    this.modal.confirm("<?php _('Confirmation required') ?>", "<?php _('Really stop current print?') ?>").then(() => {
      this.printerAction.stopPrint(this.active.slug);
    }, () => {
    });
  }
}
